Index: src/mips/full-codegen-mips.cc |
diff --git a/src/mips/full-codegen-mips.cc b/src/mips/full-codegen-mips.cc |
index 74b3807882733a4540c742f6a5dfd72f071ad534..997aa3e3d97a98cd3aa1393a46fda7cbfb35be4a 100644 |
--- a/src/mips/full-codegen-mips.cc |
+++ b/src/mips/full-codegen-mips.cc |
@@ -3748,14 +3748,11 @@ void FullCodeGenerator::EmitStringCompare(CallRuntime* expr) { |
void FullCodeGenerator::EmitMathLog(CallRuntime* expr) { |
- // Load the argument on the stack and call the stub. |
- TranscendentalCacheStub stub(TranscendentalCache::LOG, |
- TranscendentalCacheStub::TAGGED); |
+ // Load the argument on the stack and call the runtime function. |
ZoneList<Expression*>* args = expr->arguments(); |
ASSERT(args->length() == 1); |
VisitForStackValue(args->at(0)); |
- __ mov(a0, result_register()); // Stub requires parameter in a0 and on tos. |
- __ CallStub(&stub); |
+ __ CallRuntime(Runtime::kMath_log, 1); |
context()->Plug(v0); |
} |